*** |  (C) 2008-2024 Potsdam Institute for Climate Impact Research (PIK)
*** |  authors, and contributors see CITATION.cff file. This file is part
*** |  of MAgPIE and licensed under AGPL-3.0-or-later. Under Section 7 of
*** |  AGPL-3.0, you are granted additional permissions described in the
*** |  MAgPIE License Exception, version 1.0 (see LICENSE file).
*** |  Contact: magpie@pik-potsdam.de


positive variables
 vm_dem_feed(i,kap,kall)          Regional feed demand including byproducts (mio. tDM per yr)
 vm_cost_prod_livst(i,factors)    Livestock factor costs (mio. USD17MER per yr)
 vm_cost_prod_fish(i)             Fish factor costs (mio. USD17MER per yr)
 v70_investment(i,kli)            Investment in immobile farm capital (mio USD17MER per yr)
;

equations
 q70_feed(i,kap,kall)             Regional feed demand
 q70_cost_prod_liv_labor(i)       Regional labor costs for livestock production
 q70_cost_prod_liv_capital(i)     Regional investment costs in farm capital
 q70_investment(i,kli)            Regional investments into farm capital
 q70_cost_prod_fish(i)            Regional factor input costs for fish production
;

parameters
 im_slaughter_feed_share(t_all,i,kap,attributes)  Share of feed that is incorporated in animal biomass (1)
 i70_livestock_productivity(t_all,i,sys)          Productivity indicator for livestock production (t FM per animal per yr)
 im_feed_baskets(t_all,i,kap,kall)                Feed baskets in tDM per tDM livestock product (1)
 p70_cattle_stock_proxy(t,i)                      Proxy for cattle stocks needed to fullfil food demand for ruminant meat (mio. animals per yr)
 p70_milk_cow_proxy(t,i)                          Proxy for milk cows needed to fullfil food demand for milk (mio. animals per yr)
 p70_cattle_feed_pc_proxy(t,i,kli_rd)             Proxy for daily per capita feed demand for pasture biomass driven by demand for beef and dairy products (tDM per capita per day)
 p70_incr_cattle(t,i)                             Change in estimated cattle stocks attributed to food demand projections (1)
 pm_past_mngmnt_factor(t,i)                       Regional pasture management intensification factor (1)
 i70_cereal_scp_fadeout(t_all,i)                  Cereal feed fadeout (share 0-1) to be replaced by SCP (1)
 i70_foddr_scp_fadeout(t_all,i)                   Fodder fadeout (share 0-1) to be replaced by SCP (1)
 p70_country_switch(iso)                           Switch indicating whether country is affected by feed scenarios (1)
 p70_feedscen_region_shr(t_all,i)                 Weighted share of region with regards to feed scenario of countries (1)
 i70_cost_regr(i,kap,cost_regr)                   Regression coefficients for livestock factor requirements (1)
 i70_fac_req_livst(t_all,i,kli)                   Factor requirements (USD17MER per tDM)
 p70_cereal_subst_fader(t_all)                    Cereal feed substitution with SCP fader (1)
 p70_foddr_subst_fader(t_all)                     Foddr substitution with SCP fader (1)
 p70_capital_need(t,i,kli)                        Capital requirements per unit of output (USD17MER per ton DM)
 p70_capital(t,i,kli)                             Preexisting immobile capital stocks before investment (mio USD17MER)
 p70_initial_1995_prod(i,kli)                     Initial regional production of livestock products taken from 1995 (mio ton DM)
;


*#################### R SECTION START (OUTPUT DECLARATIONS) ####################
parameters
 ov_dem_feed(t,i,kap,kall,type)       Regional feed demand including byproducts (mio. tDM per yr)
 ov_cost_prod_livst(t,i,factors,type) Livestock factor costs (mio. USD17MER per yr)
 ov_cost_prod_fish(t,i,type)          Fish factor costs (mio. USD17MER per yr)
 ov70_investment(t,i,kli,type)        Investment in immobile farm capital (mio USD17MER per yr)
 oq70_feed(t,i,kap,kall,type)         Regional feed demand
 oq70_cost_prod_liv_labor(t,i,type)   Regional labor costs for livestock production
 oq70_cost_prod_liv_capital(t,i,type) Regional investment costs in farm capital
 oq70_investment(t,i,kli,type)        Regional investments into farm capital
 oq70_cost_prod_fish(t,i,type)        Regional factor input costs for fish production
;
*##################### R SECTION END (OUTPUT DECLARATIONS) #####################
